# Radial Angle Visualization
Tracks colored by the instantaneous radial angle (Angle between the center of the tissue and the cell centroid taking the origin as top left co-ordinate of the image).
As time grows the tissue also grows and we use the center of mass of the tissue at a particular time to evaluate the angle between that vector and the cell centroid vector. Color white-blue is the lowest and yellow-red highest.
![image](images/track_animation_dividing.gif)
